Icon

Enum Icon 

pub enum Icon {
    Info,
    Warning,
    Success,
    Error,
    Custom((String, Color32)),
}
An icon. If used, it will be shown next to the body of the modal.

Variants



Info

An info icon



Warning

A warning icon



Success

A success icon



Error

An error icon



Custom((String, Color32))

A custom icon. The first field in the tuple is the text of the icon, and the second field is the color.